@@ -8,7 +8,7 @@ use Parallel::Scoreboard;
 use Net::CIDR::Lite;
 use Try::Tiny;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub prepare_app {
     my $self = shift;
@@ -72,7 +72,19 @@ sub _handle_server_status {
         return [403, ['Content-Type' => 'text/plain'], [ 'Forbidden' ]];
     }
 
-    my $body="Uptime: $self->{uptime}\n";
+    my $upsince = time - $self->{uptime};
+    my $duration = "";
+    my @spans = (86400 => 'days', 3600 => 'hours', 60 => 'minutes');
+    while (@spans) {
+        my ($seconds,$unit) = (shift @spans, shift @spans);
+        if ($upsince > $seconds) {
+            $duration .= int($upsince/$seconds) . " $unit, ";
+            $upsince = $upsince % $seconds;
+        }
+    }
+    $duration .= "$upsince seconds";
+
+    my $body="Uptime: $self->{uptime} ($duration)\n";
     if ( my $scoreboard = $self->{__scoreboard} ) {
         my $stats = $scoreboard->read_all();
         my $raw_stats='';
